'use strict';

// ** Dependencies
const path = require('path');
const fs = require('fs-extra');
const errors = require('./errors');
const expand_home_dir = require('expand-home-dir');

/**
 * Expands a directory path reference with support for ~ to the home directory.
 * @param filepath
 */
function resolvePath(filepath) {
    filepath = expand_home_dir(filepath);

    // ** Determine the file path using CWD or Absolute path
    if (!path.isAbsolute(filepath)) {
        const cwd = process.cwd();
        filepath = path.resolve(cwd, filepath);
    }

    return filepath;
}

/**
 * Require a file by relative path.
 * @param filepath
 */
function requireFile(filepath) {
    filepath = resolvePath(filepath);

    // ** Ensure the file exists
    if (!fs.existsSync(filepath))
        throw errors('PATH_NOT_FOUND', 'The path to the file could not be found.', {filepath: filepath});

    // ** Load the JSON file
    return require(filepath);
}

function dirname(filepath) {
    return path.dirname(resolvePath(filepath))
}

function isDirectory(path) {
    return fs.lstatSync(path).isDirectory();
}

function isFile(path) {
    return fs.lstatSync(path).isFile();
}


// ** Exports
module.exports.resolvePath = resolvePath;
module.exports.requireFile = requireFile;
module.exports.dirname = dirname;
module.exports.isDirectory = isDirectory;
module.exports.isFile = isFile;