'use strict';

// ** Dependencies
const path = require('path');
const debug = require('debug');
const functions = require('./functions');

/**
 * Returns the name of the logger or uses the filename of who required the file
 * @param name
 * @returns {*}
 */
function getLoggerName(name) {

    if (!name) {
        // ** Load the options name from the callsite
        const caller = functions.getCallerInfo();
        const filename = caller.filename;

        // ** Don't include anything beyond the nodus-server directory

        name = path.relative(process.cwd(), filename);
        // name = trimPath(filename, 'nodus-server');
        // name = trimPath(name, 'nodus-framework');
        // name = trimPath(name, 'nodus-run.sh');
    }

    return name;
}

/**
 * Create a new instance of a logger
 * @param name - The name of the logger.  Defaults to the filename of the required file
 * @returns {*}
 */
function createLogger(name) {
    const loggerName = getLoggerName(name);

    // Return a new debug logger
    return {
        info: console.log.bind(console),
        debug: debug(loggerName),
    };
}

// ** Exports
module.exports = createLogger;
module.exports.createLogger = createLogger;